@@ -4,9 +4,12 @@
 Standard Manupilation modules that are not directly UI based.
 """
 import copy
+import os
+
 from PIL import Image
 from PyQt4.QtCore import QRect
 
+
 class ParamValues():
     def __init__(self):
         self.valR = 0
@@ -16,19 +19,29 @@ class ParamValues():
         self.valSh =0
         self.valBr = 0
         self.valCo = 0
-        self.valHi =0
-        self.valMi =0
-        self.valSw =0
+        self.valHi =5
+        self.valMi =5
+        self.valSw =5
         self.valRot = 0
+        self.GPSLat =0
+        self.GPSLatRef =1
+        self.GPSLon=0
+        self.GPSLonRef =1
         self.flipBottom = False
         self.flipRight = False
         self.flipAng = 0
+        self.valCropTop=0
+        self.valCropBottom=0
+        self.valCropLeft=0
+        self.valCropRight=0
         self.valOrient = 0
         self.valBW = "L"
         self.wMaximized = True
         self.lockUpdating = False
         self.displayUpdating = False
-        self.curImageLoc ="/opt/anselA/ui/resources/landscapeRepo.jpg"
+        self.DefaultCurImageDir =os.getcwd()+"/ui/resources/"
+        self.DefaultCurImageName ="Ansel-A-Default.jpg"
+        self.curImageLoc =self.DefaultCurImageDir+self.DefaultCurImageName
         self.plotIm =""
         
         #Current Image
@@ -39,8 +52,11 @@ class ParamValues():
         self.ApplyVisible = True #Leave true so Init_ can hide
         self.EXIFLoaded = False
         
-        self.SearchLoc = 0
+        self.SearchMMC = False
+        self.SearchOn = True
+        self.SomethingLoad = False
         self.imageDir = "/home/user/MyDocs/DCIM/"
+        self.imageDirMMC = "/media/mmc1/DCIM/"
         self.thumbsDir = "/home/user/apps/anselA/.thumbs/"
         self.cancelPlistToggle = False
         self.thumbsCount = 0
@@ -53,9 +69,14 @@ class ParamValues():
         
     def GetCurrentTab(self, Value):
         return self.valCurTab
-            
+    
+    def UndoImage_Clear(self):
+        del self.undoList_IM
+        self.undoList_IM = list() 
+        self.undoCount =0
+        
     def UndoImage_Push(self):
-        print "UndoImage_Push"
+        #print "UndoImage_Push"
         last = copy.copy(self.current)
         #last = copy.deepcopy(self.current)
         self.undoList_IM.append(last)
@@ -67,6 +88,8 @@ class ParamValues():
             self.undoCount -=1
     
     def UndoImage_Set(self):
+        ##count should be less than one but you need to pop off.
+        #reload preforms a push back.
         for i in range(int(self.undoSelected),  self.undoCount):
             self.UndoImage_Pop()
         
@@ -81,6 +104,7 @@ class ImageInfo():
     sizeDisplayImage_W = 0
     image=Image
     thumb=Image
+
     
     def setImageDisplaySize(self, DisplayPosX=0, DisplayPosY=0,  DisplayWidth=0,  DisplayHeight=0):
         self.sizeDisplayImage_H = DisplayHeight
@@ -106,3 +130,4 @@ class ImageInfo():
     def setThumb(self, image):
         thisThumb = image
     
+
