@@ -3,15 +3,15 @@
 """
 Standard Manupilation modules that are not directly UI based.
 """
-from PyQt4.QtCore import pyqtSignature
-from PIL import Image
-from filters.toolbox import *
-from core import *
-from filters.display import *
-from filters.rotate import *
-from filters.imageExif import *
-import math
 import os.path
+import time
+
+from PIL import Image
+
+from filters.display import *
+from filters.imageExif import *
+from filters.rotate import *
+from filters.toolbox import *
 
 
 def FileOpenReleased(self):
@@ -20,61 +20,91 @@ def FileOpenReleased(self):
     """
     ImgTemp= str(QtGui.QFileDialog.getOpenFileName(self, 'Open File', '/home/user/MyDocs/DCIM/', ("Images (*.png *.jpg)")))
     if ImgTemp != "":
-        self.core.current.imageageLoc = ImgTemp
-    FileImageOpen(self,  self.core.curImageLoc)
-    
+        SwitchDisplayAndLoadFile(self, ImgTemp)
+
+
+def SwitchDisplayAndLoadFile(self,  filename):
+    ShowApply(self, False)
+    ToggleThumbWait(self, True)
+    FullScreenToggle(self, False)
+    FileImageOpen(self,  filename)
+    self.core.SetCurrentTab(2)
+    self.tabStrip.setCurrentIndex(2)
+    PhotTabs_Show(self)
+    ToggleThumbWait(self, False)
+    self.repaint()
+    self.core.SomethingLoad =True
+
+
 def FileImageOpen(self,  filename):
     """
     Open File and poulate class parameters of Image.
     """
     try:
-        #ToggleThumbWait(self, True)
+        
         self.repaint()
         del self.core.undoList_IM[:]
-        self.core.current.image = (Image.open(filename))
         self.core.curImageLoc = filename
+        self.core.current.image = Image.open(self.core.curImageLoc)
+        ##Clear UndoStates
+        self.core.UndoImage_Clear()
+        ##Standard Load and refresh Image
         FileImageRefresh(self)
         
     except:
         print "Error: FileImageOpen:"+filename
-        return
+        
+    return
 
-def FileImageRefresh(self,  loadUndo=1):
-    print "FileImageRefresh"
+def FileImageRefresh(self):
+    
+    #tim=time.time()
     FileImageLoadSizes(self)
     self.core.UndoImage_Push()
     FileImageDisplayRefresh(self)
-
-        
+    #print("Image Reload Time: "+str(time.time()-tim))
+    
 def FileImageLoadSizes(self):
     try:
-        
+
         self.core.valOrient= GetExifRotation(self, self.core.curImageLoc)
         im=rotateImage(self, self.core.current.image,  self.core.valOrient)
+        ##These 2 take 1.5 seconds which is acceptable.
         w, h = im.size
-        wTh,  hTh = convertImSize(self.core, w, h,  250,  150,self.core.valOrient,  1)
-        #wTh,  hTh = convertImSize(self.core, w, h,  250,  150)
-
+        wTh,  hTh = convertImSize(self.core, w, h,  300,  180, self.core.valOrient,  1)
         size = (wTh,  hTh )
-        self.core.current.thumb = im.resize(size, Image.ANTIALIAS)
-        self.core.current.setThumbDisplaySize(155-int(wTh/2),  195-int(hTh/2), wTh, hTh)
         
+        #self.core.current.thumb = im.resize(size, Image.NEAREST) ##This takes 0.015 Seconds!!!!!
+        #self.core.current.thumb = im.resize(size, Image.BILINEAR) ##This takes 0.30 Seconds!!!!!
+        #self.core.current.thumb = im.resize(size, Image.ANTIALIAS) ##This takes 10.5 Seconds!!!!!
+        #self.core.current.thumb = im.resize(size, Image.BICUBIC) ##This takes 0.6 Seconds!!!!!
+        self.core.current.thumb = im.resize(size, Image.BILINEAR) ##This takes 0.30 Seconds!!!!!
+
+
+        self.core.current.setThumbDisplaySize(170-int(wTh/2), 200-int(hTh/2), wTh, hTh)
         w, h = self.core.current.image.size
         wTh,  hTh = convertImSize(self.core,  w, h,  796,  430)
+        
         self.core.current.setImageDisplaySize(398-int(wTh/2), 216-int(hTh/2), wTh, hTh)
+
         self.core.EXIFLoaded = False
     except:
         print "FileLoadImage Error"
 
 def FileImageDisplayRefresh(self):
     try:
-        ToggleThumbWait(self, True)
-        
-        self.photo.setGeometry(QRect(0, 0, 0, 0))
-        self.photo_Thumb.setGeometry(QRect(0, 0, 0, 0))
-        
+        tim=time.time()
+        #ToggleThumbWait(self, True)
+
+        self.photo.setGeometry(QtCore.QRect(0, 0, 0, 0))
+        self.photo_Thumb.setGeometry(QtCore.QRect(0, 0, 0, 0))
         self.photo_Thumb.setPixmap(pil2qpixmap(self.core.current.thumb))
+        ##strangly takes only 0.01s to load??
+        
+        #tim=time.time()
         self.photo.setPixmap(pil2qpixmap(self.core.current.image))
+        ##1.25 second load. ergggh
+        #print("Reload Main Image: "+str(time.time()-tim))
         
         self.photo.setGeometry(self.core.current.getImageDisplaySize())
         self.photo_Thumb.setGeometry(self.core.current.getThumbDisplaySize())
