@@ -4,6 +4,8 @@
 For Hiding and Moving.
 """
 from filters.toolbox import *
+from PyQt4 import QtCore as QtCore
+
 #######################################
 #   Display functions
 #######################################
@@ -23,16 +25,17 @@ def showUpdateLabel(self, show,  thumb):
     self.lockUpdating = show
     if (thumb == True):
         if (show == True):
-            self.labWaitThumb.setGeometry(self.photo_Thumb.geometry())
+            #self.labWaitThumb.setGeometry(self.photo_Thumb.geometry())
+            self.labWaitThumb.setGeometry(QtCore.QRect(-480, -130, 1300, 771))
         else:
-            self.labWaitThumb.setGeometry(QtCore.QRect(0, 0, 0, 0))
+            self.labWaitThumb.setGeometry(QtCore.QRect(-480, -130, 0, 771))
     else:
         if (show == True):
             WaitOverlay(self,"Updating Photo...",  "Large images may take a few seconds to process.")
             FullScreenToggle(self,True)
         else:
             FullScreenToggle(self,False)
-            WaitOverlayHide(self,)
+            WaitOverlayHide(self)
     self.repaint()
 
 def DisplayWait_Disable(self, UpdateRealImage,  Image):
@@ -56,9 +59,10 @@ def PhotTabs_Show(self):
 
 def ToggleThumbWait(self,  Show):
         if Show:
-            self.labWaitThumb.setGeometry(-30, -30, 380, 450)
+            self.labWaitThumb.setGeometry(QtCore.QRect(-480, -130, 1300, 771))
         else:
-            self.labWaitThumb.setGeometry(0, 0, 0, 0)
+            self.labWaitThumb.setGeometry(QtCore.QRect(-480, -130, 0, 771))
+        self.labWaitThumb.repaint()
 
 def ShowApply(self, Show,  First = False):
     if self.core.ApplyVisible <> Show:
