@@ -4,55 +4,164 @@
 Standard Manupilation modules that are not directly UI based.
 """
 from PIL import Image
-from PIL import ImageDraw
-from PIL import ImageEnhance
-from PyQt4.QtCore import pyqtSignature
-from filters.toolbox import *
-from filters.display import *
-from core.core import *
 
-def Adjust_ToneLevel(self, im, cSource,  UpdateRealImage):
+from filters.display import *
+from filters.toolbox import *
+
+
+def Adjust_ToneLevel(self, imageToEdit, cSource,  UpdateRealImage):
 
     if DisplayWait_Enable(self,  UpdateRealImage):
+        if UpdateRealImage:
+            im = imageToEdit
+        else:
+            im = imageToEdit.copy()
+            
         if cSource =="Any":
             if self.core.valHi <> 0:
-                im =Adjust_ToneLevelDetails(im, 170, 255, valToScalar(self.core.valHi, 40))
-            if self.core.valMi <> 0:
-                im =Adjust_ToneLevelDetails(im, 80, 170, valToScalar(self.core.valMi, 40))
+                im =Adjust_ToneLevelDetails(im, 125, 255, self.core.valHi,  self.core.valMi,  False)
+
             if self.core.valSw <> 0:
-                im =Adjust_ToneLevelDetails(im, 0, 80, valToScalar(self.core.valSw, 40))
+                im =Adjust_ToneLevelDetails(im, 1, 125, self.core.valSw, -1*self.core.valMi,  True)
         
         elif cSource =="Hi":
             if self.core.valHi <> 0:
-                im =Adjust_ToneLevelDetails(im, 170, 255, valToScalar(self.core.valHi, 40))
-        
-        elif cSource =="Mi":
-            if self.core.valMi <> 0:
-                im =Adjust_ToneLevelDetails(im, 80, 170, valToScalar(self.core.valMi, 40))
-        
+                im =Adjust_ToneLevelDetails(im, 125, 255, self.core.valHi,  self.core.valMi,  False)
+
         elif cSource =="Sw":
             if self.core.valSw <> 0:
-                im =Adjust_ToneLevelDetails(im, 0, 80, valToScalar(self.core.valSw, 40))       
+                im =Adjust_ToneLevelDetails(im, 1, 125, self.core.valSw,  -1*self.core.valMi,  True)       
         
         DisplayWait_Disable(self,  UpdateRealImage,  im)
-        
 
-def Adjust_ToneLevelDetails(im,  min, max, multi):
+
+def Adjust_ToneLevelDetails(im,  min, max, radius, multi,  shadow):
+    if multi is None:
+        multi =0
     source = im.split()
     R, G, B = 0, 1, 2
     
-    maskR = source[R].point(lambda i: ( i > min and i < max) and 255)
-    maskG = source[G].point(lambda i: ( i > min and i < max) and 255)
-    maskB = source[B].point(lambda i: ( i > min and i < max) and 255)
-
-    out = im.point(lambda i: i * multi)
+    if shadow:
+        if multi <=0:
+            mMulti=0
+        else:
+            mMulti=1.0/float(multi)
+        goal =min
+        start=min+abs(radius)*(max-min)/10
+    else:
+        if multi <=0:
+            mMulti=1
+        else:
+            mMulti=1.0/float(multi)
+        goal =min+abs(radius)*(max-min)/10
+        start=max
+    
+    maskR = source[R].point(lambda i: ( i > goal and i < start-1) and 255)
+    maskG = source[G].point(lambda i: ( i > goal and i < start-1) and 255)
+    maskB = source[B].point(lambda i: ( i > goal and i < start-1) and 255)
+    if shadow:
+        out = im.point(lambda i: i+5*multi)
+    else:
+        out = im.point(lambda i: i+5*multi)
+                       ##int(i-float(((i-goal)/2.0)))) ##int(i/(start-(i+0.001))))
+        
     im.paste(out, None, maskR)
     im.paste(out, None, maskG)
     im.paste(out, None, maskB)
     
     # build a new multiband image
-    return Image.merge(im.mode, source)
+    return  im
     
+    #Image.merge(im.mode, source)
+    
+    #            if self.core.valMi <> 0:
+#                im =Adjust_ToneLevelDetails(im, 80, 170, self.core.valMi)
+        
+#        elif cSource =="Mi":
+#            if self.core.valMi <> 0:
+#                im =Adjust_ToneLevelDetails(im, 80, 170, self.core.valMi)
+        
+        #Move to the min
+        # using shadow as the default
+        #move half the disatance of the goal value, of the multi
+        #scale the max min based on the multi, ignore midrange it's essentially contrast and a whole lot more complicated.
+        #min=0
+        #max=70
+
+def ToneLevelReset(self):
+    """
+    Slot documentation goes here.
+    """
+    self.cSlide_Hi.setValue(0)
+    self.cSlide_Mi.setValue(0)
+    self.cSlide_Sw.setValue(0)
+    self.LevelApply(self.core.curThumb,  False)
+    self.LevelApply(self.core.curIm,  True)
+    FullScreenToggle(self, True, 1)
+
+
+#def Adjust_ToneLevelDetails(im,  min, max, multi):
+#    if multi is None:
+#        multi =0
+#    source = im.split()
+#    R, G, B = 0, 1, 2
+#    
+#    if multi > 0:
+#    
+#    else:
+#    
+#    maskR = source[R].point(lambda i: ( i > min and i < max) and 255)
+#    maskG = source[G].point(lambda i: ( i > min and i < max) and 255)
+#    maskB = source[B].point(lambda i: ( i > min and i < max) and 255)
+#
+#    out = im.point(lambda i: i + multi)
+#    im.paste(out, None, maskR)
+#    im.paste(out, None, maskG)
+#    im.paste(out, None, maskB)
+#    
+#    # build a new multiband image
+#    return im# Image.merge(im.mode, source)
+#
+#
+#The point method can be used to translate the pixel values of an image (e.g. image contrast
+#manipulation). In most cases, a function object expecting one argument can be passed to the
+#this method. Each pixel is processed according to that function:
+#Applying point transforms
+#
+## multiply each pixel by 1.2
+#out = im.point(lambda i: i * 1.2)
+#
+#Using the above technique, you can quickly apply any simple expression to an image.
+#You can also combine the point and paste methods to selectively modify an image:
+#Processing individual bands
+#
+## split the image into individual bands
+#source = im.split()
+#
+#R, G, B = 0, 1, 2
+#
+## select regions where red is less than 100
+#mask = source[R].point(lambda i: i < 100 and 255)
+#
+## process the green band
+#out = source[G].point(lambda i: i * 0.7)
+#
+## paste the processed band back, but only where red was < 100
+#source[G].paste(out, None, mask)
+#
+## build a new multiband image
+#im = Image.merge(im.mode, source)
+#
+#Note the syntax used to create the mask:
+#
+#    imout = im.point(lambda i: expression and 255)
+#
+#Python only evaluates the portion of a logical expression as is
+#necessary to determine the outcome, and returns the last value
+#examined as the result of the expression. So if the expression above
+#is false (0), Python does not look at the second operand, and thus returns 0.
+#Otherwise, it returns 255.
+
 
 #        if self.core.valHi <> 0:
 #            out = source[R].point(lambda i: i *valToScalar(self.core.valHi))
@@ -95,56 +204,3 @@ def Adjust_ToneLevelDetails(im,  min, max, multi):
 #
 #        im = Image.merge(im.mode, source)
 
-
-
-def ToneLevelReset(self):
-    """
-    Slot documentation goes here.
-    """
-    self.cSlide_Hi.setValue(0)
-    self.cSlide_Mi.setValue(0)
-    self.cSlide_Sw.setValue(0)
-    self.LevelApply(self.core.curThumb,  False)
-    self.LevelApply(self.core.curIm,  True)
-    FullScreenToggle(self, True, 1)
-
-#
-#
-#The point method can be used to translate the pixel values of an image (e.g. image contrast
-#manipulation). In most cases, a function object expecting one argument can be passed to the
-#this method. Each pixel is processed according to that function:
-#Applying point transforms
-#
-## multiply each pixel by 1.2
-#out = im.point(lambda i: i * 1.2)
-#
-#Using the above technique, you can quickly apply any simple expression to an image.
-#You can also combine the point and paste methods to selectively modify an image:
-#Processing individual bands
-#
-## split the image into individual bands
-#source = im.split()
-#
-#R, G, B = 0, 1, 2
-#
-## select regions where red is less than 100
-#mask = source[R].point(lambda i: i < 100 and 255)
-#
-## process the green band
-#out = source[G].point(lambda i: i * 0.7)
-#
-## paste the processed band back, but only where red was < 100
-#source[G].paste(out, None, mask)
-#
-## build a new multiband image
-#im = Image.merge(im.mode, source)
-#
-#Note the syntax used to create the mask:
-#
-#    imout = im.point(lambda i: expression and 255)
-#
-#Python only evaluates the portion of a logical expression as is
-#necessary to determine the outcome, and returns the last value
-#examined as the result of the expression. So if the expression above
-#is false (0), Python does not look at the second operand, and thus returns 0.
-#Otherwise, it returns 255.
