@@ -4,15 +4,12 @@
 Standard Manupilation modules that are not directly UI based.
 """
 import math
-from PIL import Image
-from core.core import *
+
+from PIL import Image, ImageDraw
+
 from filters.display import *
-from PIL import ImageDraw
-from PIL import ImageEnhance
-from PyQt4 import QtCore as QtCore
-from PyQt4 import QtGui as QtGui 
 from filters.toolbox import pil2qpixmap
-from PyQt4.QtCore import pyqtSignature
+
 
 #     out = im.transpose(Image.FLIP_LEFT_RIGHT)
 #     out = im.transpose(Image.FLIP_TOP_BOTTOM)
@@ -29,6 +26,8 @@ def rotateImage(self, image, ExifRot=0):
             return image.rotate(180)
         elif (ExifRot == 270):  
             return image.rotate(-270)
+        else:
+            return image
     else:
         return image
 
@@ -51,16 +50,16 @@ def RotateCalc(self, rotation, im):
     pi2 = math.pi/2
 
     if( theta >= 0.0 and theta < pi2 ): #0 - 1.57 
-        return([botOps,botOps, int(w-botOps),  int(h-botOps)]) 
+        return([int(botOps),int(botOps), int(w-botOps),  int(h-botOps)]) 
     elif( theta >= pi2 and theta < math.pi): # 1.57 - 3.14
-        return([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
+        return([int(botOps), int(botAdj), int(w-botOps),  int(h-botAdj)]) 
     elif( theta >= math.pi and theta < (math.pi + pi2) ): # 3.14 - 4.71
-        return([botOps, botOps, int(w-botOps),  int(h-botOps)]) 
+        return([int(botOps), int(botOps), int(w-botOps),  int(h-botOps)]) 
     elif( theta >= (math.pi + pi2)):  # 4.71 - 6.28 ok 
-        return([botOps, botAdj, int(w-botOps),  int(h-botAdj)]) 
+        return([int(botOps), int(botAdj), int(w-botOps),  int(h-botAdj)]) 
 
 
-@pyqtSignature("int")
+##@pyqtSignature("int")
 def RotateThumb(self, rotation):
     showUpdateLabel(self, True,  True)
     im=self.core.current.thumb
@@ -74,7 +73,7 @@ def RotateThumb(self, rotation):
     showUpdateLabel(self, False,  True)
     
 
-@pyqtSignature("int")    
+##@pyqtSignature("int")    
 def RotateApply(self, rotation):
     if  (self.core.lockUpdating == False):
         showUpdateLabel(self, True,  False)
@@ -100,7 +99,7 @@ def RotateApply(self, rotation):
         self.core.lockUpdating = False
 
 
-@pyqtSignature("int,Bool,Bool")
+##@pyqtSignature("int,Bool,Bool")
 def FlipThumb(self):
     showUpdateLabel(self, True,  True)
     im=self.core.current.thumb
@@ -112,11 +111,17 @@ def FlipThumb(self):
         
     if self.core.flipAng==90:
         im = im.transpose(Image.ROTATE_90) 
+        w=self.photo_Thumb.width()
+        h=self.photo_Thumb.height()
+        self.photo_Thumb.setGeometry(self.photo_Thumb.y(), self.photo_Thumb.x(), h, w)
     elif  self.core.flipAng==180:
         im = im.transpose(Image.ROTATE_90) 
         im = im.transpose(Image.ROTATE_90) 
     elif  self.core.flipAng==270:    
         im = im.transpose(Image.ROTATE_270) 
+        w=self.photo_Thumb.width()
+        h=self.photo_Thumb.height()
+        self.photo_Thumb.setGeometry(self.photo_Thumb.y(), self.photo_Thumb.x(), h, w)
         
     self.photo_Thumb.setPixmap(pil2qpixmap(im))
     showUpdateLabel(self, False,  True)
