@@ -3,10 +3,10 @@
 """
 Standard Manupilation modules that are not directly UI based.
 """
-from PyQt4 import QtGui as QtGui 
-from PyQt4 import QtCore as QtCore
-from PyQt4.QtCore import pyqtSignature
 import math
+from PyQt4.QtCore import QRect
+from PyQt4 import QtGui as QtGui 
+
 
 def Enhance(self, im, name, lo, hi):
 # set up the image
@@ -15,12 +15,14 @@ def Enhance(self, im, name, lo, hi):
     self.update("1.0") # normalize
 
     self.value = eval(value)
-    
-def MinMax():
-    if (self.isFullScreen):
-        self.showFullScreen()
-    else:
-        self.showNormal()
+        
+def ScaleLabel(self, xW, yH, w, h):
+    """
+    Send widget x(Width), y(Height) of center point
+    and h,w of image passed.
+    """
+    return QRect(xW-int(w/2), yH-int(h/2), w, h)
+
 
 def pil2qpixmap(pil_image):
     try:
@@ -37,13 +39,16 @@ def valToScalar(value, range=20):
     """
     Calculates an appropiate value to scale from / to
     """
-   
-    if (value >0):
-        return 1+value/float(range)
-    if (value <0):
-        return 1+(value*(1/float(range)))
-    if (value ==0):
+    if value is None:
         return 1
+    else:
+        if (value >0):
+            return 1+value/float(range)
+        if (value <0):
+            return 1+(value*(1/float(range)))
+        if (value ==0):
+            return 1
+            
 
 def convertImSize(core, origW,  origH,  wConstraint,  hConstraint,  rotation=0,  sizeMutable=0):
     """
@@ -54,7 +59,7 @@ def convertImSize(core, origW,  origH,  wConstraint,  hConstraint,  rotation=0,
     widgetRatio = float(wConstraint)/float(hConstraint)
     imageRatio = float(origW)/float(origH)
 
-    if (imageRatio >= widgetRatio ): #landscape 
+    if (imageRatio >= widgetRatio): #landscape 
         scale=origW/float(wConstraint)
         newW=wConstraint
         newH=int(math.ceil(origH/scale))
