@@ -3,39 +3,29 @@
 """
 Module implementing MainWindow GUI, anselA
 """
-import glob
-import math
-import operator
 import os
-import time
 import sys
 import webbrowser
-from subprocess import call
 
 from PIL import Image
-from PIL import ImageDraw
-from PIL import ImageEnhance
 from PyQt4 import QtCore as QtCore
-from PyQt4 import QtGui as QtGui 
-from PyQt4.QtCore import pyqtSignature
+from PyQt4 import QtGui as QtGui
 from PyQt4.QtGui import QMainWindow
 
-from imports.EXIF import *
-from core.config import *
 from core.browser import *
-from core.core import *
 from core.buttons import *
+from core.config import *
+from core.core import *
 from core.files import *
 from filters.bw import *
 from filters.colors import *
+from filters.crop import *
 from filters.histogram import *
 from filters.imageExif import *
 from filters.levels import *
 from filters.rotate import *
-from filters.toolbox import *
 from filters.simple import *
 from ui.Ui_mainWindow import Ui_MainWindow
-from filters.toolbox import pil2qpixmap
 
 
 class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
@@ -62,7 +52,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
             
     def postShow(self):
         try:
-            ReadConfig(self)
+            ##ReadConfig(self)
             PhotTabs_Hide(self)
             WaitOverlay(self,"Starting...")
             ##FullScreenToggle(self,True, 2)
@@ -71,22 +61,51 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
             self.photo.setMouseTracking= True
             populatePhotoList(self)
             WaitOverlayHide(self)
-            self.listPhotositemLoad(self.listPhotos.item(0))
             ##reply = QtGui.QMessageBox.question(self, 'Message',"Are you sure to quit?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
        
             if (self.listPhotos.item(0) == None):
                 FileImageOpen(self,  self.core.curImageLoc)
             ShowApply(self, False)
-            self.core.plotIm=Image.open("/opt/anselA/ui/resources/graph.png") 
+            self.core.plotIm=Image.open("ui/resources/graph.png") 
         except:
-            print "Error: postShow"
+            print "Error: Init Fail"
             
+    #######################################
+    #   Tabs Change
+    #######################################
+    
+    def on_tabPhoto_currentChanged(self, index):
+        if (self.tabPhoto.count != 1):
+            if (index == 2):
+                ##self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
+                if self.core.thumbsCount == 0:
+                    return populatePhotoList(self)
+                self.photoListZoom.setVisible(False)
+            elif (index ==1):
+               self.loadUndoImages()
+        else:
+            #self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
+            if self.core.thumbsCount == 0:
+                return populatePhotoList(self)
+
+    def on_tabStrip_currentChanged(self, index):
+        if (index==9):
+            self.FramePopup.setGeometry(QtCore.QRect(0, 0, 800, 480))
+        elif  (index==6):
+            ReturnHistPlots(self)
+        elif (index==0):
+            self.PopulateEXIFData(self.core.curImageLoc)
+        elif (index==7):
+            self.core.SetCurrentTab(self.tabStrip.currentIndex())
+            self.PopSizes()
+        else:
+            self.core.SetCurrentTab(self.tabStrip.currentIndex())
 
     #######################################
     #   Color Sliders
     #######################################
     def on_cSlide_B_valueChanged(self, value):
-        self.core.valB = cSlide_SetValue(self, value,  self.core.valB,  self.lcdB, self.cSlide_B,  "B")
+        self.core.valB = cSlide_SetValue(self, value,  self.core.valB,  self.lcdB, self.cSlide_B,  "B", self.core.displayUpdating)
     def on_btnSlide_B_dn_pressed(self):
         self.core.valB -= 1
         self.cSlide_B.setValue(self.core.valB)
@@ -95,7 +114,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.cSlide_B.setValue(self.core.valB)        
         
     def on_cSlide_R_valueChanged(self, value):
-        self.core.valR = cSlide_SetValue(self, value,  self.core.valR,  self.lcdR, self.cSlide_R,  "R")
+        self.core.valR = cSlide_SetValue(self, value,  self.core.valR,  self.lcdR, self.cSlide_R,  "R", self.core.displayUpdating)
     def on_btnSlide_R_dn_pressed(self):
         self.core.valR -= 1
         self.cSlide_R.setValue(self.core.valR)
@@ -104,7 +123,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.cSlide_R.setValue(self.core.valR)
         
     def on_cSlide_G_valueChanged(self, value):
-        self.core.valG = cSlide_SetValue(self, value,  self.core.valG,  self.lcdG, self.cSlide_G,  "G")        
+        self.core.valG = cSlide_SetValue(self, value,  self.core.valG,  self.lcdG, self.cSlide_G,  "G", self.core.displayUpdating)        
     def on_btnSlide_G_dn_pressed(self):
         self.core.valG -= 1
         self.cSlide_G.setValue(self.core.valG)
@@ -118,7 +137,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     #   Level Applys
     #######################################
     def on_cSlide_Hi_valueChanged(self, value):
-        self.core.valHi = cSlide_SetValue(self, value,  self.core.valHi,  self.lcdHi, self.cSlide_Hi,  "Hi")
+        self.core.valHi = cSlide_SetValue(self, value,  self.core.valHi,  self.lcdHi, self.cSlide_Hi,  "Hi", self.core.displayUpdating)
     def on_btnSlide_H_dn_pressed(self):
         self.core.valHi -= 1
         self.cSlide_Hi.setValue(self.core.valHi)
@@ -127,7 +146,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.cSlide_Hi.setValue(self.core.valHi)
   
     def on_cSlide_Mi_valueChanged(self, value):
-        self.core.valMi = cSlide_SetValue(self, value,  self.core.valMi,  self.lcdMi_2, self.cSlide_Mi,  "Mi")
+        self.core.valMi = cSlide_SetValue(self, value,  self.core.valMi,  self.lcdMi, self.cSlide_Mi,  "Any", self.core.displayUpdating)
     def on_btnSlide_Mid_dn_pressed(self):
         self.core.valMi -= 1
         self.cSlide_Mi.setValue(self.core.valMi)            
@@ -136,7 +155,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.cSlide_Mi.setValue(self.core.valMi)
 
     def on_cSlide_Sw_valueChanged(self, value):
-        self.core.valSw = cSlide_SetValue(self, value,  self.core.valSw,  self.lcdSw, self.cSlide_Sw,  "Sw")        
+        self.core.valSw = cSlide_SetValue(self, value,  self.core.valSw,  self.lcdSw, self.cSlide_Sw,  "Sw", self.core.displayUpdating)        
     def on_btnSlide_Sha_dn_pressed(self):
         self.core.valSw -= 1
         self.cSlide_Sw.setValue(self.core.valSw)
@@ -148,7 +167,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     #   Simple Applys
     #######################################
     def on_cSlide_Co_valueChanged(self, value):
-        self.core.valCo = cSlide_SetValue(self, value,  self.core.valCo,  self.lcdCo, self.cSlide_Co,  "Co")
+        self.core.valCo = cSlide_SetValue(self, value,  self.core.valCo,  self.lcdCo, self.cSlide_Co,  "Co", self.core.displayUpdating)
     def on_btnSlide_Co_dn_pressed(self):
         self.core.valCo -= 1
         self.cSlide_Co.setValue(self.core.valCo)
@@ -157,7 +176,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.cSlide_Co.setValue(self.core.valCo)
     
     def on_cSlide_Sh_valueChanged(self, value):
-        self.core.valSh = cSlide_SetValue(self, value,  self.core.valSh,  self.lcdSh, self.cSlide_Sh,  "Sh")            
+        self.core.valSh = cSlide_SetValue(self, value,  self.core.valSh,  self.lcdSh, self.cSlide_Sh,  "Sh", self.core.displayUpdating)            
     def on_btnSlide_Sh_dn_pressed(self):
         self.core.valSh -= 1
         self.cSlide_Sh.setValue(self.core.valSh)
@@ -166,7 +185,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.cSlide_Sh.setValue(self.core.valSh)
         
     def on_cSlide_Sa_valueChanged(self, value):
-        self.core.valSa = cSlide_SetValue(self, value,  self.core.valSa,  self.lcdSa, self.cSlide_Sa,  "Sa")    
+        self.core.valSa = cSlide_SetValue(self, value,  self.core.valSa,  self.lcdSa, self.cSlide_Sa,  "Sa", self.core.displayUpdating)    
     def on_btnSlide_Sa_up_pressed(self):
         self.core.valSa += 1
         self.cSlide_Sa.setValue(self.core.valSa)
@@ -175,7 +194,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.cSlide_Sa.setValue(self.core.valSa)
     
     def on_cSlide_Br_valueChanged(self, value):
-        self.core.valBr = cSlide_SetValue(self, value,  self.core.valBr,  self.lcdBr, self.cSlide_Br,  "Br")
+        self.core.valBr = cSlide_SetValue(self, value,  self.core.valBr,  self.lcdBr, self.cSlide_Br,  "Br", self.core.displayUpdating)
     def on_btnSlide_Br_dn_pressed(self):
         self.core.valBr -= 1
         self.cSlide_Br.setValue(self.core.valBr)
@@ -230,7 +249,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     #   Rotation
     ####################################### 
             
-    @pyqtSignature("int")
+    ##@pyqtSignature("int")
     def on_dial_valueChanged(self, value):
         if  self.ResetRotSliders("Dial"):
             self.core.valRot = value
@@ -292,6 +311,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     #######################################
 
     def on_btnExitCancel_released(self):
+        self.showFullScreen()
         self.tabStrip.setCurrentIndex(self.core.GetCurrentTab(self))
         self.FramePopup.setGeometry(QtCore.QRect(0, 0, 0, 0))
         
@@ -299,36 +319,19 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         sys.exit()
     
     def on_btnPopCancel_released(self):
+        self.showFullScreen()
         self.tabStrip.setCurrentIndex(self.core.GetCurrentTab(self))
         self.FramePopup.setGeometry(QtCore.QRect(0, 0, 0, 0))
 
-    def on_minMax_released(self):
-        return MinMax()
-        
     def on_photo_released(self):
         QMessageBox.information(self, "Loading Data", "Please wait while the data is retrieved...")
 
-   
     def on_btnOpen_released(self):
         return FileOpenReleased(self)
-       
+    
     def PopulateEXIFData(self,  filename):
         return ImageExifLoad(self)
-        
-    def on_tabPhoto_currentChanged(self, index):
-        if (self.tabPhoto.count != 1):
-            if (index == 2):
-                ##self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
-                if self.core.thumbsCount == 0:
-                    return populatePhotoList(self)
-                self.photoListZoom.setVisible(False)
-            elif (index ==1):
-               self.loadUndoImages()
-        else:
-            #self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
-            if self.core.thumbsCount == 0:
-                return populatePhotoList(self)
-                
+    
     def loadUndoImages(self):
         self.btnUndoCancel.setVisible(False)
         self.btnUndoGo.setVisible(False)
@@ -354,36 +357,33 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     def on_btnFullScreenClose_released(self):
         FullScreenToggle(self,False)
     
-    def on_tabStrip_currentChanged(self, index):
-        if (index==9):
-            self.FramePopup.setGeometry(QtCore.QRect(0, 0, 800, 480))
-        elif  (index==6):
-            ReturnHistPlots(self)
-        elif (index==7):
-            self.PopulateEXIFData(self.core.curImageLoc)
-        else:
-            self.core.SetCurrentTab(self.tabStrip.currentIndex() )
-            
+
     #######################################
     #   Photo Browser
     #######################################
-
     def on_btnPListCancel_released(self):
         self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 0, 0))
         self.core.populatePhotoList = False
 
     def on_btnPlistZoom_released(self):
-        AnimateWidget(self, self.photoListZoom, 155-int(self.photoListZoom.width()/2) , 195-int(self.photoListZoom.height()/2), 0, 0, 10)
+        ##AnimateWidget(self, self.photoListZoom, 170-int(self.photoListZoom.width()/2) , 200-int(self.photoListZoom.height()/2), 0, 0, 7)
+        LoadCurImageFromPhotoBrowser(self)
+
+    def on_btnEdit_pressed(self):
+        ##AnimateWidget(self, self.photoListZoom, 40, 0, 0, 0, 10)
+        LoadCurImageFromPhotoBrowser(self)
+
+    def on_listPhotos_itemDoubleClicked(self, item):
+        ##((155-int(self.photoListZoom.width()/2)) , 0, 0, 0, 10))
+        ##AnimateWidget(self, self.photoListZoom, 170-int(self.photoListZoom.width()/2) , 200-int(self.photoListZoom.height()/2), 0, 0, 10)
         LoadCurImageFromPhotoBrowser(self)
 
     def on_butReturn_released(self):
+        if not self.core.SomethingLoad:
+            self.listPhotositemLoad(self.listPhotos.item(0))
+            LoadCurImageFromPhotoBrowser(self)
         FullScreenToggle(self,False)
     
-    def on_listPhotos_itemDoubleClicked(self, item):
-        #((155-int(self.photoListZoom.width()/2)) , 0, 0, 0, 10))
-        AnimateWidget(self, self.photoListZoom, 155-int(self.photoListZoom.width()/2) , 195-int(self.photoListZoom.height()/2), 0, 0, 10)
-        LoadCurImageFromPhotoBrowser(self)
-    
     def on_btnReloadPList_released(self):
         self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 800, 480))
     
@@ -407,10 +407,9 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
     def on_listPhotos_itemClicked(self, item):
        #return listPhotosClicked()
         if str(item.text()) == "Load More...":
-            self.core.thumbsCount +=100
+            self.core.thumbsCount +=70
             populatePhotoList(self,  False)
 
-            self.btnEditZoomed.setGeometry(QtCore.QRect(40, 120, 250, 150))
         else:
             self.listPhotositemLoad(item)
             
@@ -422,8 +421,8 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
             item.rotation= GetExifRotation(self, item.imageLocation)
             im = rotateImage(self, im, item.rotation)
             
-            wTh,  hTh = convertImSize(self.core, im.size[0], im.size[1],  250,  150, item.rotation,  1) #This should be the same size as the thumbnailbnails
-            item.setIconZoomSize(self.ScaleLabel(195,  400, hTh, wTh))
+            wTh,  hTh = convertImSize(self.core, im.size[0], im.size[1],  300,  180, item.rotation,  1) #This should be the same size as the thumbnailbnails
+            item.setIconZoomSize(ScaleLabel(self, 170, 200, wTh, hTh))
             
             self.photoListZoom.setGeometry(item.getIconZoomSize())
             self.btnPlistZoom.setGeometry(self.photoListZoom.geometry())
@@ -445,13 +444,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         self.btnUndoGo.setText("Revert to "+str(item.text()))
 
 
-    @pyqtSignature("int, int, int, int")
-    def ScaleLabel(self, yH, xW, h, w):
-        """
-        Send widget x(Width), y(Height) of center point
-        and h,w of image passed.
-        """
-        return QtCore.QRect(xW-int(w/2), yH-int(h/2), w, h)
+
     
     #######################################
     #   Apply and Undo
@@ -528,12 +521,9 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
         WaitOverlayHide(self,)
         
     def on_btnApplyUndo_pressed(self):
+        self.loadUndoImages()
         FullScreenToggle(self,True,  1)
     
-    def on_btnEdit_pressed(self):
-        AnimateWidget(self, self.photoListZoom, 40, 0, 0, 0, 10)
-        LoadCurImageFromPhotoBrowser(self)
-    
     def on_btnRefreshExp_pressed(self):
         if (str(self.btnRefreshExp.text()) =="+"):
             self.btnRefreshExp.setText("-")
@@ -544,26 +534,97 @@ class MainWindow(QMainWindow, Ui_MainWindow,  ParamValues):
             self.btnRefreshExp.setText("+")
             self.btnReloadPList.setGeometry(QtCore.QRect(400, 370, 111, 0))
             self.btnOpen.setGeometry(QtCore.QRect(510, 370, 111, 0)) 
+            self.btnRefresh.setGeometry(QtCore.QRect(200, 370, 151, 0))
     
-    def on_SearchPhoto_Mcc_toggled(self, checked):
-        if (checked):
-           SetConfig_SearchSettings(self, 1)
-        else:
-            SetConfig_SearchSettings(self, 0)
     
     def on_btnSaveSettings_pressed(self):
-        WriteConfig(self)
+        populatePhotoList(self, True)
+        
 
     #######################################
     #   Web Buttons
     #######################################
     def on_btnBlog_pressed(self):
-        url='http://ansel-a.blogspot.com/'
-        os.system('browser --url=%s' %url)
+        try:
+            webbrowser.open_new('http://ansel-a.blogspot.com/')     
+        except:
+            return
+        #url='http://ansel-a.blogspot.com/'      #os.system('browser --url=%s' %url)
         
     def on_btnBug_released(self):
-        url='https://bugs.maemo.org/enter_bug.cgi?product=AnselA'
-        os.system('browser --url=%s' %url)
-
+        try:
+            webbrowser.open_new('https://bugs.maemo.org/enter_bug.cgi?product=AnselA')     
+        except:
+            return
+        
     def on_btnPopMinimize_released(self):
-         ui.hide()
+        self.showNormal()
+    
+    #######################################
+    #   Crop and Resize  Buttons
+    #######################################  
+    def PopSizes(self):
+        w, h = self.core.current.image.size
+        self.core.valCropTop=0
+        self.core.valCropBottom=h
+        self.core.valCropLeft=0
+        self.core.valCropRight=w
+        self.txtSize_W.setText(str(w))
+        self.txtSize_H.setText(str(h))
+        self.txtSize_T.setText(str(self.core.valCropTop))
+        self.txtSize_L.setText(str(self.core.valCropLeft))
+        self.txtSize_B.setText(str(self.core.valCropBottom))
+        self.txtSize_R.setText(str(self.core.valCropRight))
+    
+    def on_cropScrollTop_valueChanged(self, value):
+        if self.core.displayUpdating == False:
+            w,  h = self.core.current.image.size
+            self.core.valCropTop=int((h*(float(value)/100.0)))
+            if self.core.valCropTop >= self.core.valCropBottom:
+                self.core.valCropTop = self.core.valCropBottom
+            self.txtSize_T.setText(str(self.core.valCropTop))
+            CropThumb(self)    
+   
+    def on_cropScrollBottom_valueChanged(self, value):
+        if self.core.displayUpdating == False:
+            w,  h = self.core.current.image.size
+            self.core.valCropBottom=int(h*(float(value)/100.0))
+            if self.core.valCropBottom <= self.core.valCropTop:
+                self.core.valCropBottom = self.core.valCropTop
+            self.txtSize_B.setText(str(self.core.valCropBottom))
+            CropThumb(self)
+    
+    def on_cropScrollLeft_valueChanged(self, value):
+        if self.core.displayUpdating == False:
+            w,  h = self.core.current.image.size
+            self.core.valCropLeft=int((w*(float(value)/100.0)))
+            if self.core.valCropLeft >= self.core.valCropRight:
+                self.core.valCropLeft = self.core.valCropRight
+            self.txtSize_L.setText(str(self.core.valCropLeft))
+            CropThumb(self)
+        
+    def on_cropScrollRight_valueChanged(self, value):
+        if self.core.displayUpdating == False:
+            w,  h = self.core.current.image.size
+            self.core.valCropRight=int(w*(float(value)/100.0))
+            if self.core.valCropLeft >= self.core.valCropRight:
+                self.core.valCropRight = self.core.valCropLeft
+                self.core.valCropRight = self.core.valCropLeft
+            self.txtSize_R.setText(str(self.core.valCropRight))
+            CropThumb(self)
+    
+    def on_btnShowMap_pressed(self):
+        self.webView.load(QtCore.QUrl("http://maps.google.com/maps/api/staticmap?center=" + str(self.core.GPSLatRef*self.core.GPSLat) + "," + str(self.core.GPSLonRef*self.core.GPSLon) + "&zoom=14&size=450x350&maptype=roadmap&markers=color:blue|" + str(self.core.GPSLatRef*self.core.GPSLat) + "," + str(self.core.GPSLonRef*self.core.GPSLon) + "&sensor=false"))
+        self.labLatLon.setText("Photo GPS Position - Lat:" + str(self.core.GPSLatRef*self.core.GPSLat) + ",Lon:" + str(self.core.GPSLonRef*self.core.GPSLon))
+        self.webView.show()
+        self.frameBrowserMap.setGeometry(QtCore.QRect(0, 0, 800, 480))
+    
+    def on_btnMapClose_pressed(self):
+        self.frameBrowserMap.setGeometry(QtCore.QRect(0, 0, 0, 480))
+    
+
+    def on_SearchPhoto_On_toggled(self, checked):
+        self.core.SearchOn = checked
+        
+    def on_SearchPhoto_Mcc_toggled(self, checked):
+        self.core.SearchMMC = checked
